==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/sql/kotlin/inputs/SyncGroupSchemaTableArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.sql.kotlin.inputs

import com.pulumi.azurenative.sql.inputs.SyncGroupSchemaTableArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Properties of table in sync group schema.
 * @property columns List of columns in sync group schema.
 * @property quotedName Quoted name of sync group schema table.
 */
public data class SyncGroupSchemaTableArgs(
    public val columns: Output<List<SyncGroupSchemaTableColumnArgs>>? = null,
    public val quotedName: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.sql.inputs.SyncGroupSchemaTableArgs> {
    override fun toJava(): com.pulumi.azurenative.sql.inputs.SyncGroupSchemaTableArgs =
        com.pulumi.azurenative.sql.inputs.SyncGroupSchemaTableArgs.builder()
            .columns(
                columns?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .quotedName(quotedName?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [SyncGroupSchemaTableArgs].
 */
@PulumiTagMarker
public class SyncGroupSchemaTableArgsBuilder internal constructor() {
    private var columns: Output<List<SyncGroupSchemaTableColumnArgs>>? = null

    private var quotedName: Output<String>? = null

    /**
     * @param value List of columns in sync group schema.
     */
    @JvmName("xbicncbrwbqkbjck")
    public suspend fun columns(`value`: Output<List<SyncGroupSchemaTableColumnArgs>>) {
        this.columns = value
    }

    @JvmName("inkjwjupywnxtcbo")
    public suspend fun columns(vararg values: Output<SyncGroupSchemaTableColumnArgs>) {
        this.columns = Output.all(values.asList())
    }

    /**
     * @param values List of columns in sync group schema.
     */
    @JvmName("msowqvvfojjudhxy")
    public suspend fun columns(values: List<Output<SyncGroupSchemaTableColumnArgs>>) {
        this.columns = Output.all(values)
    }

    /**
     * @param value Quoted name of sync group schema table.
     */
    @JvmName("qvnlxphhbgrhmotr")
    public suspend fun quotedName(`value`: Output<String>) {
        this.quotedName = value
    }

    /**
     * @param value List of columns in sync group schema.
     */
    @JvmName("beohohsxfewgrvqo")
    public suspend fun columns(`value`: List<SyncGroupSchemaTableColumnArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.columns = mapped
    }

    /**
     * @param argument List of columns in sync group schema.
     */
    @JvmName("wxgrgttgsgbkuysw")
    public suspend
    fun columns(argument: List<suspend SyncGroupSchemaTableColumnArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            SyncGroupSchemaTableColumnArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.columns = mapped
    }

    /**
     * @param argument List of columns in sync group schema.
     */
    @JvmName("lmtvgwfibmbluxrp")
    public suspend fun columns(
        vararg
        argument: suspend SyncGroupSchemaTableColumnArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            SyncGroupSchemaTableColumnArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.columns = mapped
    }

    /**
     * @param argument List of columns in sync group schema.
     */
    @JvmName("cbeadycmgkagxvas")
    public suspend fun columns(argument: suspend SyncGroupSchemaTableColumnArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            SyncGroupSchemaTableColumnArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.columns = mapped
    }

    /**
     * @param values List of columns in sync group schema.
     */
    @JvmName("ylrgfuyqfouqphwq")
    public suspend fun columns(vararg values: SyncGroupSchemaTableColumnArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.columns = mapped
    }

    /**
     * @param value Quoted name of sync group schema table.
     */
    @JvmName("eepidywevkrohrjd")
    public suspend fun quotedName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.quotedName = mapped
    }

    internal fun build(): SyncGroupSchemaTableArgs = SyncGroupSchemaTableArgs(
        columns = columns,
        quotedName = quotedName,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/sql/kotlin/inputs/SyncGroupSchemaTableArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.sql.kotlin.inputs

import com.pulumi.azurenative.sql.inputs.SyncGroupSchemaTableArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Properties of table in sync group schema.
 * @property columns List of columns in sync group schema.
 * @property quotedName Quoted name of sync group schema table.
 */
public data class SyncGroupSchemaTableArgs(
    public val columns: Output<List<SyncGroupSchemaTableColumnArgs>>? = null,
    public val quotedName: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.sql.inputs.SyncGroupSchemaTableArgs> {
    override fun toJava(): com.pulumi.azurenative.sql.inputs.SyncGroupSchemaTableArgs =
        com.pulumi.azurenative.sql.inputs.SyncGroupSchemaTableArgs.builder()
            .columns(
                columns?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .quotedName(quotedName?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [SyncGroupSchemaTableArgs].
 */
@PulumiTagMarker
public class SyncGroupSchemaTableArgsBuilder internal constructor() {
    private var columns: Output<List<SyncGroupSchemaTableColumnArgs>>? = null

    private var quotedName: Output<String>? = null

    /**
     * @param value List of columns in sync group schema.
     */
    @JvmName("rmefyambuipywbhp")
    public suspend fun columns(`value`: Output<List<SyncGroupSchemaTableColumnArgs>>) {
        this.columns = value
    }

    @JvmName("dpwvbxpjnomvltev")
    public suspend fun columns(vararg values: Output<SyncGroupSchemaTableColumnArgs>) {
        this.columns = Output.all(values.asList())
    }

    /**
     * @param values List of columns in sync group schema.
     */
    @JvmName("ipgfbsvnafmhfrtf")
    public suspend fun columns(values: List<Output<SyncGroupSchemaTableColumnArgs>>) {
        this.columns = Output.all(values)
    }

    /**
     * @param value Quoted name of sync group schema table.
     */
    @JvmName("xcavaettyvglklkn")
    public suspend fun quotedName(`value`: Output<String>) {
        this.quotedName = value
    }

    /**
     * @param value List of columns in sync group schema.
     */
    @JvmName("rhewsocouaedbrpr")
    public suspend fun columns(`value`: List<SyncGroupSchemaTableColumnArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.columns = mapped
    }

    /**
     * @param argument List of columns in sync group schema.
     */
    @JvmName("qykxtiypnsqbidge")
    public suspend
    fun columns(argument: List<suspend SyncGroupSchemaTableColumnArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            SyncGroupSchemaTableColumnArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.columns = mapped
    }

    /**
     * @param argument List of columns in sync group schema.
     */
    @JvmName("sjurnourgpxsptyi")
    public suspend fun columns(
        vararg
        argument: suspend SyncGroupSchemaTableColumnArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            SyncGroupSchemaTableColumnArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.columns = mapped
    }

    /**
     * @param argument List of columns in sync group schema.
     */
    @JvmName("nkpyucswysdblhsp")
    public suspend fun columns(argument: suspend SyncGroupSchemaTableColumnArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            SyncGroupSchemaTableColumnArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.columns = mapped
    }

    /**
     * @param values List of columns in sync group schema.
     */
    @JvmName("awiqhbspenclgvky")
    public suspend fun columns(vararg values: SyncGroupSchemaTableColumnArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.columns = mapped
    }

    /**
     * @param value Quoted name of sync group schema table.
     */
    @JvmName("emsfyrfvxdbivgcx")
    public suspend fun quotedName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.quotedName = mapped
    }

    internal fun build(): SyncGroupSchemaTableArgs = SyncGroupSchemaTableArgs(
        columns = columns,
        quotedName = quotedName,
    )
}
